gchecky.model.buyer_billing_address_t

Package gchecky :: Module model :: Class buyer_billing_address_t |
[hide private]
[frames] | no frames]

# Class buyer_billing_address_t

source code

    object --+
             |
     gxml.Node --+
                 |
         address_t --+
                     |
                    buyer_billing_address_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
Inherited from `address_t`: `address1`, `address2`, `city`, `company_name`, `contact_name`, `country_code`, `email`, `fax`, `phone`, `postal_code`, `region`, `structured_name` Inherited from `address_t` (private): `_fields`

Properties | [hide private]
Inherited from `object`: `__class__`